.. _symptomen:

#########
symptomen
#########

.. include:: VERGIFTIGING

bijwerkingen
============

.. include:: BIJWERKING

negatieve symptomen
===================

.. include:: DOPAMINE

ontwenning
==========

.. include:: ONTWENNING
